==> lincd-dcmi-0.1.6.tgz: package/src/ontologies/dcterms.ts <==
import {NamedNode} from 'lincd/lib/models';
import {JSONLD} from 'lincd-jsonld/lib/utils/JSONLD';
import {createNameSpace} from 'lincd/lib/utils/NameSpace';
import {linkedOntology} from '../package';
import * as _this from './dcterms';

export var loadData = () => JSONLD.parsePromise(import('../data/dcterms.json'));

export var ns = createNameSpace('http://purl.org/dc/terms/');

export var _self: NamedNode = ns('');

// Classes
export var AgentClass: NamedNode = ns('AgentClass');
export var Agent:NamedNode = ns('Agent');
export var BibliographicResource:NamedNode = ns('BibliographicResource');
export var FileFormat:NamedNode = ns('FileFormat');
export var Frequency:NamedNode = ns('Frequency');
export var Jurisdiction:NamedNode = ns('Jurisdiction');
export var LicenseDocument:NamedNode = ns('LicenseDocument');
export var LinguisticSystem:NamedNode = ns('LinguisticSystem');
export var Location:NamedNode = ns('Location');
export var LocationPeriodOrJurisdiction:NamedNode = ns('LocationPeriodOrJurisdiction');
export var MediaType:NamedNode = ns('MediaType');
export var MediaTypeOrExtent:NamedNode = ns('MediaTypeOrExtent');
export var MethodOfAccrual:NamedNode = ns('MethodOfAccrual');
export var MethodOfInstruction:NamedNode = ns('MethodOfInstruction');
export var PeriodOfTime:NamedNode = ns('PeriodOfTime');
export var PhysicalMedium:NamedNode = ns('PhysicalMedium');
export var PhysicalResource:NamedNode = ns('PhysicalResource');
export var Policy:NamedNode = ns('Policy');
export var ProvenanceStatement:NamedNode = ns('ProvenanceStatement');
export var RightsStatement:NamedNode = ns('RightsStatement');
export var SizeOrDuration:NamedNode = ns('SizeOrDuration');
export var Standard:NamedNode = ns('Standard');

// Properties
export var abstract: NamedNode = ns('abstract');
export var accessRights: NamedNode = ns('accessRights');
export var accrualMethod: NamedNode = ns('accrualMethod');
export var accrualPeriodicity: NamedNode = ns('accrualPeriodicity');
export var accrualPolicy: NamedNode = ns('accrualPolicy');
export var alternative: NamedNode = ns('alternative');
export var audience: NamedNode = ns('audience');
export var available: NamedNode = ns('available');
export var bibliographicCitation: NamedNode = ns('bibliographicCitation');
export var conformsTo: NamedNode = ns('conformsTo');
export var contributor: NamedNode = ns('contributor');
export var coverage: NamedNode = ns('coverage');
export var created: NamedNode = ns('created');
export var creator: NamedNode = ns('creator');
export var date: NamedNode = ns('date');
export var dateAccepted: NamedNode = ns('dateAccepted');
export var dateCopyrighted: NamedNode = ns('dateCopyrighted');
export var dateSubmitted: NamedNode = ns('dateSubmitted');
export var description: NamedNode = ns('description');
export var educationLevel: NamedNode = ns('educationLevel');
export var extent: NamedNode = ns('extent');
export var format: NamedNode = ns('format');
export var hasFormat: NamedNode = ns('hasFormat');
export var hasPart: NamedNode = ns('hasPart');
export var hasVersion: NamedNode = ns('hasVersion');
export var identifier: NamedNode = ns('identifier');
export var instructionalMethod: NamedNode = ns('instructionalMethod');
export var isFormatOf: NamedNode = ns('isFormatOf');
export var isPartOf: NamedNode = ns('isPartOf');
export var isReferencedBy: NamedNode = ns('isReferencedBy');
export var isReplacedBy: NamedNode = ns('isReplacedBy');
export var isRequiredBy: NamedNode = ns('isRequiredBy');
export var issued: NamedNode = ns('issued');
export var isVersionOf: NamedNode = ns('isVersionOf');
export var language: NamedNode = ns('language');
export var license: NamedNode = ns('license');
export var mediator: NamedNode = ns('mediator');
export var medium: NamedNode = ns('medium');
export var modified: NamedNode = ns('modified');
export var provenance: NamedNode = ns('provenance');
export var publisher: NamedNode = ns('publisher');
export var references: NamedNode = ns('references');
export var relation: NamedNode = ns('relation');
export var replaces: NamedNode = ns('replaces');
export var requires: NamedNode = ns('requires');
export var rights: NamedNode = ns('rights');
export var rightsHolder: NamedNode = ns('rightsHolder');
export var source: NamedNode = ns('source');
export var spatial: NamedNode = ns('spatial');
export var subject: NamedNode = ns('subject');
export var tableOfContents: NamedNode = ns('tableOfContents');
export var temporal: NamedNode = ns('temporal');
export var title: NamedNode = ns('title');
export var type: NamedNode = ns('type');
export var valid: NamedNode = ns('valid');
export var Image: NamedNode = ns('Image');


export const dcterms = {
  abstract,
  accessRights,
  accrualMethod,
  accrualPeriodicity,
  accrualPolicy,
  alternative,
  audience,
  available,
  bibliographicCitation,
  conformsTo,
  contributor,
  coverage,
  created,
  creator,
  date,
  dateAccepted,
  dateCopyrighted,
  dateSubmitted,
  description,
  educationLevel,
  extent,
  format,
  hasFormat,
  hasPart,
  hasVersion,
  identifier,
  instructionalMethod,
  isFormatOf,
  isPartOf,
  isReferencedBy,
  isReplacedBy,
  isRequiredBy,
  issued,
  isVersionOf,
  language,
  license,
  mediator,
  medium,
  modified,
  provenance,
  publisher,
  references,
  relation,
  replaces,
  requires,
  rights,
  rightsHolder,
  source,
  spatial,
  subject,
  tableOfContents,
  temporal,
  title,
  type,
  valid,
  Agent,
  AgentClass,
  BibliographicResource,
  FileFormat,
  Frequency,
  Jurisdiction,
  LicenseDocument,
  LinguisticSystem,
  Location,
  LocationPeriodOrJurisdiction,
  MediaType,
  MediaTypeOrExtent,
  MethodOfAccrual,
  MethodOfInstruction,
  PeriodOfTime,
  PhysicalMedium,
  PhysicalResource,
  Policy,
  ProvenanceStatement,
  RightsStatement,
  SizeOrDuration,
  Standard,


};

linkedOntology(_this, ns, 'dcterms', loadData, '../data/dcterms.json');

==> lincd-dcmi-0.1.7.tgz: package/src/ontologies/dcterms.ts <==
import {NamedNode} from 'lincd/lib/models';
import {JSONLD} from 'lincd-jsonld/lib/utils/JSONLD';
import {createNameSpace} from 'lincd/lib/utils/NameSpace';
import {linkedOntology} from '../package';
import * as _this from './dcterms';

export var loadData = () => JSONLD.parsePromise(import('../data/dcterms.json'));

export var ns = createNameSpace('http://purl.org/dc/terms/');

export var _self: NamedNode = ns('');

// Classes
export var AgentClass: NamedNode = ns('AgentClass');
export var Agent: NamedNode = ns('Agent');
export var BibliographicResource: NamedNode = ns('BibliographicResource');
export var FileFormat: NamedNode = ns('FileFormat');
export var Frequency: NamedNode = ns('Frequency');
export var Jurisdiction: NamedNode = ns('Jurisdiction');
export var LicenseDocument: NamedNode = ns('LicenseDocument');
export var LinguisticSystem: NamedNode = ns('LinguisticSystem');
export var Location: NamedNode = ns('Location');
export var LocationPeriodOrJurisdiction: NamedNode = ns(
  'LocationPeriodOrJurisdiction',
);
export var MediaType: NamedNode = ns('MediaType');
export var MediaTypeOrExtent: NamedNode = ns('MediaTypeOrExtent');
export var MethodOfAccrual: NamedNode = ns('MethodOfAccrual');
export var MethodOfInstruction: NamedNode = ns('MethodOfInstruction');
export var PeriodOfTime: NamedNode = ns('PeriodOfTime');
export var PhysicalMedium: NamedNode = ns('PhysicalMedium');
export var PhysicalResource: NamedNode = ns('PhysicalResource');
export var Policy: NamedNode = ns('Policy');
export var ProvenanceStatement: NamedNode = ns('ProvenanceStatement');
export var RightsStatement: NamedNode = ns('RightsStatement');
export var SizeOrDuration: NamedNode = ns('SizeOrDuration');
export var Standard: NamedNode = ns('Standard');

// Properties
export var abstract: NamedNode = ns('abstract');
export var accessRights: NamedNode = ns('accessRights');
export var accrualMethod: NamedNode = ns('accrualMethod');
export var accrualPeriodicity: NamedNode = ns('accrualPeriodicity');
export var accrualPolicy: NamedNode = ns('accrualPolicy');
export var alternative: NamedNode = ns('alternative');
export var audience: NamedNode = ns('audience');
export var available: NamedNode = ns('available');
export var bibliographicCitation: NamedNode = ns('bibliographicCitation');
export var conformsTo: NamedNode = ns('conformsTo');
export var contributor: NamedNode = ns('contributor');
export var coverage: NamedNode = ns('coverage');
export var created: NamedNode = ns('created');
export var creator: NamedNode = ns('creator');
export var date: NamedNode = ns('date');
export var dateAccepted: NamedNode = ns('dateAccepted');
export var dateCopyrighted: NamedNode = ns('dateCopyrighted');
export var dateSubmitted: NamedNode = ns('dateSubmitted');
export var description: NamedNode = ns('description');
export var educationLevel: NamedNode = ns('educationLevel');
export var extent: NamedNode = ns('extent');
export var format: NamedNode = ns('format');
export var hasFormat: NamedNode = ns('hasFormat');
export var hasPart: NamedNode = ns('hasPart');
export var hasVersion: NamedNode = ns('hasVersion');
export var identifier: NamedNode = ns('identifier');
export var instructionalMethod: NamedNode = ns('instructionalMethod');
export var isFormatOf: NamedNode = ns('isFormatOf');
export var isPartOf: NamedNode = ns('isPartOf');
export var isReferencedBy: NamedNode = ns('isReferencedBy');
export var isReplacedBy: NamedNode = ns('isReplacedBy');
export var isRequiredBy: NamedNode = ns('isRequiredBy');
export var issued: NamedNode = ns('issued');
export var isVersionOf: NamedNode = ns('isVersionOf');
export var language: NamedNode = ns('language');
export var license: NamedNode = ns('license');
export var mediator: NamedNode = ns('mediator');
export var medium: NamedNode = ns('medium');
export var modified: NamedNode = ns('modified');
export var provenance: NamedNode = ns('provenance');
export var publisher: NamedNode = ns('publisher');
export var references: NamedNode = ns('references');
export var relation: NamedNode = ns('relation');
export var replaces: NamedNode = ns('replaces');
export var requires: NamedNode = ns('requires');
export var rights: NamedNode = ns('rights');
export var rightsHolder: NamedNode = ns('rightsHolder');
export var source: NamedNode = ns('source');
export var spatial: NamedNode = ns('spatial');
export var subject: NamedNode = ns('subject');
export var tableOfContents: NamedNode = ns('tableOfContents');
export var temporal: NamedNode = ns('temporal');
export var title: NamedNode = ns('title');
export var type: NamedNode = ns('type');
export var valid: NamedNode = ns('valid');
export var Image: NamedNode = ns('Image');

export const dcterms = {
  abstract,
  accessRights,
  accrualMethod,
  accrualPeriodicity,
  accrualPolicy,
  alternative,
  audience,
  available,
  bibliographicCitation,
  conformsTo,
  contributor,
  coverage,
  created,
  creator,
  date,
  dateAccepted,
  dateCopyrighted,
  dateSubmitted,
  description,
  educationLevel,
  extent,
  format,
  hasFormat,
  hasPart,
  hasVersion,
  identifier,
  instructionalMethod,
  isFormatOf,
  isPartOf,
  isReferencedBy,
  isReplacedBy,
  isRequiredBy,
  issued,
  isVersionOf,
  language,
  license,
  mediator,
  medium,
  modified,
  provenance,
  publisher,
  references,
  relation,
  replaces,
  requires,
  rights,
  rightsHolder,
  source,
  spatial,
  subject,
  tableOfContents,
  temporal,
  title,
  type,
  valid,
  Agent,
  AgentClass,
  BibliographicResource,
  FileFormat,
  Frequency,
  Jurisdiction,
  LicenseDocument,
  LinguisticSystem,
  Location,
  LocationPeriodOrJurisdiction,
  MediaType,
  MediaTypeOrExtent,
  MethodOfAccrual,
  MethodOfInstruction,
  PeriodOfTime,
  PhysicalMedium,
  PhysicalResource,
  Policy,
  ProvenanceStatement,
  RightsStatement,
  SizeOrDuration,
  Standard,
};

linkedOntology(_this, ns, 'dcterms', loadData, '../data/dcterms.json');
